Changelog
=========

0.1.0 (2018-12-12)
------------------

- Feat: add release script. [Jose Diaz-Gonzalez]

- Add support for Python 3 (up to Python 3.7) [Xavier Hardy]

  Add tox.ini file
  Add gitignore


0.0.4 (2013-12-13)
------------------

- Change assertDictEquals to assertEquals. [Clay Pence]

- Allow using custom config parser. [Clay Pence]

  Instead of using ConfigParser.ConfigParser, let the user pass
  in a parser.


0.0.3 (2013-05-23)
------------------

- Allow overriding the confd_path from an entry in the main config.
  [Jose Diaz-Gonzalez]

0.0.2 (2013-04-18)
------------------

- Fix issue where main section was not always created. [Jose Diaz-
  Gonzalez]

0.0.1 (2013-04-14)
------------------

- Initial commit. [Jose Diaz-Gonzalez]


